@@ -105,7 +105,7 @@ class ClassificationScore:
          #A list of all the prediction csv files, path object
          self.predictions = list(Path(predictions).glob('*.csv')) 
          #Segmentation image for accurate metric evaluation
-         self.segimage = segimage
+         self.segimage = imread(segimage)
          #Approximate locations of the ground truth, Z co ordinate wil be ignored
          self.groundtruth = groundtruth
          self.thresholdscore = thresholdscore
@@ -180,6 +180,7 @@ class ClassificationScore:
 
          df = pd.DataFrame(data, columns=columns)
          df.to_csv(str(self.csv_pred.parent) + '_Model_Accuracy' + '.csv')
+         print(df)
          return df
 
      
@@ -199,7 +200,8 @@ class ClassificationScore:
                         tp  = tp + 1
                 else:
                         fp = fp + 1        
-            
+            tp = tp / len(self.location_pred) * 100
+            fp = fp / len(self.location_pred) * 100
             fn = self._FalseNegatives()
             return tp, fn, fp, len(self.location_pred), len(self.location_gt)
         
@@ -217,7 +219,7 @@ class ClassificationScore:
 
                             if spacedistance > self.thresholdspace or timedistance > self.thresholdtime:
                                     fn  = fn + 1
-
+                        fn = fn/len(self.location_gt) * 100
                         return fn
                     
                                 
